datablock ProjectileData(staticHitscanGunProjectile : gunProjectile)
{
    projectileShapeName = gunProjectile.projectileShapeName;

	uiName = "";
	effectiveRange		 = 150;		// effective range
	totalRange			 = 2000;	// total range
	
	unitsPerSecond		 = 1500;	// how many torque units the projectile should travel in one second
									// the default static shape is designed for ranges in 
									// the 800 - 2000 u/s range, anything slower will lag 
									// visually.
	
	gravityScale 		 = 0.7;		// scale gravity effect outside effective range
	swayMod				 = 0.5;		// scale wind effect outside effective range
	
	spawnFakeProjectiles = true;	// use animated static shape to give the illusion of a visible projectile
	tracerEffect		 = false;	// use red tracer effect
	
	scaleCalibre		 = 0.3;		// bullet scale on diameter axis
	scaleLength			 = 1;		// bullet scale on length axis
	
	isSupersonic		 = true;	// enable/disable supersonic crack effect on near miss
	isSuppressive		 = true;	// enable/disable suppression effects
	suppressionRadius    = 18;		// distance the bullet must near-miss the player by in order to cause suppression effects
	
	allowRicochet		 = true;	// enable/disable bullet ricochet
	ricoMinimumAngle 	 = 40; 		// minimum angle that can ricochet
	ricoChanceCurve 	 = 5; 		// the higher, the more common ricochet is
	ricoRarity 			 = 3;		// higher = less common rico
									// https://www.desmos.com/calculator/p6ywpi0sud
	
	particleEmitter      = "";
};
datablock ProjectileData(staticHitscanGunTracerProjectile : staticHitscanGunProjectile)
{
	tracerEffect		 = true;
};
datablock ProjectileData(staticHitscanGunRicochetProjectile : staticHitscanGunProjectile)
{
	// custom ricochet projectile
	// slower round, more affected by gravity and wind, more likely to ricochet
	unitsPerSecond 		= 900;
	effectiveRange 		= 0;
	totalRange 			= 1000;
	gravityScale		= 2;
	swayMod 			= 2;
	isSupersonic 		= false;
	allowRicochet		= true;
	ricoMinimumAngle 	= 40;
	ricoChanceCurve 	= 5;
	ricoRarity 			= 1;
};

datablock ItemData(staticHitscanGunItem : gunItem)
{
	shapeFile = "add-ons/weapon_gun/pistol.dts";
	doColorShift = true;
	colorShiftColor = "0.35 0.25 0.25 1.000";
	image = staticHitscanGunImage;
	uiName = "Hitscan Gun";
};
datablock ShapeBaseImageData(staticHitscanGunImage : gunImage)
{
	shapeFile = "add-ons/weapon_gun/pistol.dts";
	doColorShift = true;
	colorShiftColor = staticHitscanGunItem.colorShiftColor;
};

function staticHitscanGunImage::onFire(%this,%obj,%slot)
{
	// animation
	if(%obj.getDamagePercent() < 1.0)
		%obj.playThread(2, shiftAway);

	// get info about our muzzle and shooter
	%muzzlePoint = %obj.getMuzzlePoint(0);
	%muzzleVector = %obj.getMuzzleVector(0);
	%client = %obj.client;
	
	// spawn a tracer every 3rd shot
	if(!(%obj.shotNo_[%this]++ % 3))
		%datablock = staticHitscanGunTracerProjectile;
	else
		%datablock = staticHitscanGunProjectile;
		
	// spread is handled in support_staticHitscan by default. you can still
	// define your own spread by setting this to 0 and adjusting the vector
	// yourself.
	%spread = 0.0001;
		
	// zeroing allows you to account for bullet drop by adjusting the bullet
	// trajectory up and down. this will cause the bullet to cross your
	// sight plane twice, so shooting at close targets while zero'd for
	// far targets will cause you to shoot above your target.
	%zero = 0.003;
	
	// create projectile
	createStaticHitscan(%client, %muzzlePoint, %muzzleVector, %datablock, %spread, %zero);
}

function staticHitscanGunProjectile::onRicochet(%this, %obj, %pos, %reflectVec)
{
	// custom ricochet functionality. Since staticHitscanGunProjectile has field allowRicochet set to true
	// the script will look for staticHitscanGunProjectile::onRicochet and call it. If this function were
	// not defined, it would just simply call createStaticHitscan again using the reflection vector and the
	// previous values that were used in the onFire state.
	// If allowRicochet was set to false, nothing would happen.
	
	// This function is called after the script has determined that a ricochet has occured.
	// talk("Ricochet occured!");
	
	// In this example, I use this functionality to call another static hitscan using a different
	// projectile, with a little bit of random spread. This projectile is specifically designed for
	// ricochet.
	createStaticHitscan(%obj.client, %pos, %reflectVec, staticHitscanGunRicochetProjectile, 0.0001);
	return;
}

// Since this weapon uses multiple projectiles, I have to set them to adopt the base projectile's
// ricochet functionality. This includes the ricochet projectile itself.
function staticHitscanGunTracerProjectile::onRicochet(%this, %obj, %pos, %reflectVec)
{
	staticHitscanGunProjectile::onRicochet(%this, %obj, %pos, %reflectVec);
}
function staticHitscanGunRicochetProjectile::onRicochet(%this, %obj, %pos, %reflectVec)
{
	staticHitscanGunProjectile::onRicochet(%this, %obj, %pos, %reflectVec);
}